@@ -23,7 +23,7 @@ ll <- function(pos=1, unit="KB", digits=0, dim=FALSE, sort=FALSE, class=NULL,
   get.object.size <- function(object.name, pos)
   {
     object <- get(object.name, pos=pos)
-    size <- try(unclass(object.size(object)), silent=TRUE)
+    size <- try(unclass(utils::object.size(object)), silent=TRUE)
     if(inherits(size, "try-error"))
       size <- 0
     size
